# Load required libraries
library(ggplot2)
library(dplyr)

# Function to safely write CSV
safe_write_csv <- function(x, file) {
  tryCatch({
    write.csv(x, file, row.names = FALSE)
    cat("Successfully wrote", file, "\n")
  }, error = function(e) {
    cat("Error writing", file, ":", conditionMessage(e), "\n")
  })
}

# Function to safely save plot
safe_ggsave <- function(filename, plot, ...) {
  tryCatch({
    ggsave(filename, plot, ...)
    cat("Successfully saved", filename, "\n")
  }, error = function(e) {
    cat("Error saving", filename, ":", conditionMessage(e), "\n")
  })
}

# Print current working directory
cat("Current working directory:", getwd(), "\n")

# Read the data
tryCatch({
  data <- read.csv("C:/Users/talil/Desktop/ISR_analysis/ISR_exp2/ISR_exp2.csv")
  cat("Successfully read the CSV file\n")
}, error = function(e) {
  cat("Error reading CSV file:", conditionMessage(e), "\n")
  stop("Cannot proceed without data")
})

# Calculate pairwise differences
data$diff <- data$can_same - data$can_diff

# Calculate quantiles for ISR in each condition
data$quantile_can_same <- rank(data$can_same) / nrow(data)
data$quantile_can_diff <- rank(data$can_diff) / nrow(data)

# Create a dataframe with all subjects' data
all_subjects <- data %>%
  select(subject, can_same, can_diff, diff, quantile_can_same, quantile_can_diff) %>%
  arrange(diff)

# Write the data for all subjects to a CSV file
safe_write_csv(all_subjects, "C:/Users/talil/Desktop/ISR_analysis/ISR_exp2/all_subjects_with_ISR_quantiles.csv")

# Perform correlation analysis
correlation_test <- cor.test(data$quantile_can_same, data$diff)

# Prepare correlation results
correlation_results <- paste0(
  "Correlation Analysis Results:\n",
  "Correlation coefficient (r): ", round(correlation_test$estimate, 4), "\n",
  "p-value: ", format.pval(correlation_test$p.value, digits = 4), "\n",
  "Direction: ", ifelse(correlation_test$estimate > 0, "Positive", "Negative"), "\n",
  "The correlation is ", ifelse(correlation_test$p.value < 0.05, "significant", "not significant"), " at the 0.05 level.\n"
)

# Print correlation results to console
cat(correlation_results)

# Save correlation results to a text file
tryCatch({
  writeLines(correlation_results, "C:/Users/talil/Desktop/ISR_analysis/ISR_exp2/correlation_results.txt")
  cat("Successfully wrote correlation_results.txt\n")
}, error = function(e) {
  cat("Error writing correlation_results.txt:", conditionMessage(e), "\n")
})

# Calculate summary statistics
summary_stats <- data %>%
  summarise(
    mean_diff = mean(diff),
    sd_diff = sd(diff),
    n = n(),
    ci_lower = mean_diff - qt(0.975, df = n - 1) * sd_diff / sqrt(n),
    ci_upper = mean_diff + qt(0.975, df = n - 1) * sd_diff / sqrt(n)
  )

# Calculate percentiles
percentiles <- quantile(data$diff, probs = c(0.1, 0.3, 0.5, 0.7, 0.9))

# Create the pairwise differences plot
p <- ggplot() +
  geom_jitter(data = data, aes(x = "", y = diff), width = 0.2, alpha = 0.5, size = 3) +
  geom_hline(yintercept = 0, linetype = "dashed", color = "gray50") +
  geom_point(data = summary_stats, aes(x = "", y = mean_diff), color = "red", size = 5) +
  geom_errorbar(data = summary_stats, 
                aes(x = "", ymin = ci_lower, ymax = ci_upper), 
                width = 0.1, color = "red", size = 1) +
  geom_hline(yintercept = percentiles, linetype = "dotted", color = "blue") +
  scale_y_continuous(
    limits = function(x) {
      range <- range(c(x, 0))
      c(floor(range[1] * 2) / 2, ceiling(range[2] * 2) / 2)
    },
    breaks = function(x) seq(floor(x[1] * 2) / 2, ceiling(x[2] * 2) / 2, by = 0.5)
  ) +
  labs(x = "", y = "ISR Difference (can_same - can_diff)",
       title = "Pairwise Differences: can_same - can_diff") +
  theme_minimal(base_size = 22) +
  theme(
    text = element_text(family = "Arial"),
    plot.background = element_rect(fill = "white", color = NA),
    panel.background = element_rect(fill = "white", color = NA),
    axis.text.x = element_blank(),
    axis.ticks.x = element_blank(),
    plot.title = element_text(hjust = 0.5, size = 24, face = "bold"),
    axis.title.y = element_text(size = 22),
    axis.text.y = element_text(size = 22)
  )

# Save the pairwise differences plot
safe_ggsave("C:/Users/talil/Desktop/ISR_analysis/ISR_exp2/ISR_pairwise_differences_can.png", 
            plot = p, width = 6, height = 10, dpi = 300, bg = "white")

# Create a scatter plot for correlation
correlation_plot <- ggplot(data, aes(x = quantile_can_same, y = diff)) +
  geom_point(alpha = 0.5) +
  geom_smooth(method = "lm", color = "red") +
  labs(x = "Quantile of can_same", y = "Difference (can_same - can_diff)",
       title = "Correlation: can_same Quantile vs Difference") +
  theme_minimal(base_size = 16) +
  theme(
    text = element_text(family = "Arial"),
    plot.title = element_text(hjust = 0.5, size = 20, face = "bold")
  )

# Save the correlation plot
safe_ggsave("C:/Users/talil/Desktop/ISR_analysis/ISR_exp2/ISR_correlation_plot_can_same.png", 
            plot = correlation_plot, width = 8, height = 6, dpi = 300, bg = "white")

cat("Script execution completed.\n")